@@ -457,10 +457,7 @@ RM_STATUS NV_API_CALL os_memcpy_from_user(
     NvU32 length
 )
 {
-    if (src < (void *) VM_MAXUSER_ADDRESS)
-        return copyin(src, dst, length)  ? RM_ERR_INVALID_POINTER : RM_OK;
-
-    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+    return copyin(src, dst, length)  ? RM_ERR_INVALID_POINTER : RM_OK;
 }
 
 RM_STATUS NV_API_CALL os_memcpy_to_user(
@@ -469,10 +466,7 @@ RM_STATUS NV_API_CALL os_memcpy_to_user(
     NvU32 length
 )
 {
-    if (dst < (void *) VM_MAXUSER_ADDRESS)
-        return copyout(src, dst, length) ? RM_ERR_INVALID_POINTER : RM_OK;
-
-    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+    return copyout(src, dst, length) ? RM_ERR_INVALID_POINTER : RM_OK;
 }
 
 void* NV_API_CALL os_mem_set(
