@@ -901,9 +901,9 @@ RM_STATUS NV_API_CALL nv_agp_init(
         return RM_ERR_NO_FREE_MEM;
     }
 
-    VM_OBJECT_LOCK(sc->AGP_object);
+    VM_OBJECT_WLOCK(sc->AGP_object);
     vm_object_set_memattr(sc->AGP_object, VM_MEMATTR_WRITE_COMBINING);
-    VM_OBJECT_UNLOCK(sc->AGP_object);
+    VM_OBJECT_WUNLOCK(sc->AGP_object);
 
     return RM_OK;
 
